/***************************************************************
 * Name:      bitmapcombobox.cpp
 * Purpose:   Code for Dialog bitmapcombobox
 * Author:    Salvador Pozo (salvapozo@gmail.com)
 * Created:   2024-11-27
 * Copyright: Salvador Pozo (https://conclase.net)
 * License:
 **************************************************************/

#include "bitmapcombobox.h"
#include "bullet_blue16x16.xpm"
#include "bullet_green16x16.xpm"
#include "bullet_red16x16.xpm"
#include "bullet_yellow16x16.xpm"

IMPLEMENT_DYNAMIC_CLASS( bcbValidator, wxValidator )
BEGIN_EVENT_TABLE( bcbValidator, wxValidator )
END_EVENT_TABLE()

bcbValidator::bcbValidator(wxString *v) : wxValidator(), m_valor(v) {}

bool bcbValidator::TransferFromWindow()
{
    try {
        wxBitmapComboBox *lb = dynamic_cast<wxBitmapComboBox*>(m_validatorWindow);
        *m_valor = lb->GetValue();
    }
    catch (...) {
        wxFAIL_MSG( _T("bcbValidator sólo funciona con wxBitmapComboBox"));
        return false;
    }
    return true;
}

bool bcbValidator::TransferToWindow()
{
    return true;
}

bool bcbValidator::Validate(wxWindow* parent)
{
    return true;
}

wxBEGIN_EVENT_TABLE(bitmapcombobox, wxDialog)
    EVT_CLOSE(bitmapcombobox::OnClose)
wxEND_EVENT_TABLE()

bitmapcombobox::bitmapcombobox(wxWindow *wnd, datosBitmapComboBox &datos)
    : wxDialog(wnd, -1, _T("Ejemplo de bitmapcombobox")), data(datos)
{
    wxBoxSizer *boxVertical;
    wxBoxSizer *boxHorizontal;

    boxVertical = new wxBoxSizer(wxVERTICAL);

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);
    m_comboBox = new wxBitmapComboBox(this, idBitmapComboBox, data.opcion, wxDefaultPosition, wxSize(200, wxDefaultCoord), data.lista, wxCB_DROPDOWN, bcbValidator(&data.opcion));
    boxHorizontal->Add(m_comboBox, wxSizerFlags().Border());
    boxVertical->Add(boxHorizontal, wxSizerFlags().Border(wxTOP).Right());

    std::vector<wxBitmapBundle> bmp;
    bmp.push_back(wxBitmapBundle(bullet_green));
    bmp.push_back(wxBitmapBundle(bullet_yellow));
    bmp.push_back(wxBitmapBundle(bullet_blue));
    bmp.push_back(wxBitmapBundle(bullet_red));
    for(size_t i=0; i<data.lista.GetCount(); i++) {
        m_comboBox->SetItemBitmap(i, bmp[data.color[i]]);
    }

    boxVertical->Add(CreateStdDialogButtonSizer(wxOK | wxCANCEL), wxSizerFlags().Border());

    SetSizerAndFit(boxVertical);
}

bitmapcombobox::~bitmapcombobox()
{
    //dtor
}

void bitmapcombobox::OnClose(wxCloseEvent& event) {
    Destroy();
}


