/***************************************************************
 * Name:      wx009Main.cpp
 * Purpose:   Code for Application Frame
 * Author:    Salvador Pozo (salvador@conclase.net)
 * Created:   2024-11-27
 * Copyright: Salvador Pozo (www.conclase.net)
 * License:
 **************************************************************/

#ifdef WX_PRECOMP
#include "wx_pch.h"
#endif

#include <fstream>
#include "wx009Main.h"

//helper functions
enum wxbuildinfoformat {
    short_f, long_f };

wxString wxbuildinfo(wxbuildinfoformat format)
{
    wxString wxbuild(wxVERSION_STRING);

    if (format == long_f )
    {
#if defined(__WXMSW__)
        wxbuild << _T("-Windows");
#elif defined(__WXMAC__)
        wxbuild << _T("-Mac");
#elif defined(__UNIX__)
        wxbuild << _T("-Linux");
#endif

#if wxUSE_UNICODE
        wxbuild << _T("-Unicode build");
#else
        wxbuild << _T("-ANSI build");
#endif // wxUSE_UNICODE
    }

    return wxbuild;
}

BEGIN_EVENT_TABLE(wx009Frame, wxFrame)
    EVT_CLOSE(wx009Frame::OnClose)
    EVT_MENU(idMenuQuit, wx009Frame::OnQuit)
    EVT_MENU(idMenuAbout, wx009Frame::OnAbout)
    EVT_MENU(idMenuComboBox, wx009Frame::OnComboBox)
    EVT_MENU(idMenuBitmapComboBox, wx009Frame::OnBitmapComboBox)
END_EVENT_TABLE()

wx009Frame::wx009Frame(wxFrame *frame, const wxString& title)
    : wxFrame(frame, -1, title),
      dataCombobox(),
      dataBitmapCombobox(_T("verde"), {_T("verde"), _T("amarillo"), _T("azul"), _T("rojo")}, {0, 1, 2, 3})
{
    wxImage::AddHandler(new wxPNGHandler);

    LeerLista(dataCombobox.lista);

    // create a menu bar
    wxMenuBar* mbar = new wxMenuBar();
    wxMenu* fileMenu = new wxMenu(_T(""));
    fileMenu->Append(idMenuComboBox, _T("&ComboBox"), _T("Ejemplo ComboBox"));
    fileMenu->Append(idMenuBitmapComboBox, _T("&BitmapComboBox"), _T("Ejemplo BitmapComboBox"));
    fileMenu->Append(idMenuQuit, _T("&Salir\tAlt-F4"), _T("Salir de la aplicación"));
    mbar->Append(fileMenu, _T("&Fichero"));

    wxMenu* helpMenu = new wxMenu(_T(""));
    helpMenu->Append(idMenuAbout, _T("&Sobre\tF1"), _T("Muestra información sobre la aplicación"));
    mbar->Append(helpMenu, _T("&Ayuda"));

    SetMenuBar(mbar);

    // create a status bar with some information about the used wxWidgets version
    CreateStatusBar(2);
    SetStatusText(_("Hola"),0);
    SetStatusText(wxbuildinfo(short_f), 1);
}

void wx009Frame::LeerLista(wxArrayString &lista) {
    std::fstream fe("opciones.txt", std::ios::in);
    char cad[200];
    size_t i=0;
    do {
        fe.getline(cad, 200, '\n');
        if(!fe.eof()) lista.Add(cad);
        i++;
    } while(!fe.eof());
}

void wx009Frame::GuardarLista(wxArrayString &lista) {
    std::fstream fs("opciones.txt", std::ios::out);
    for(size_t i=0; i<lista.GetCount(); i++) {
        fs << lista[i] << "\n";
    }
}

wx009Frame::~wx009Frame()
{
    GuardarLista(dataCombobox.lista);
}

void wx009Frame::OnClose(wxCloseEvent &event)
{
    Destroy();
}

void wx009Frame::OnQuit(wxCommandEvent &event)
{
    Destroy();
}

void wx009Frame::OnAbout(wxCommandEvent &event)
{
    wxString msg = wxbuildinfo(long_f);
    wxMessageBox(msg, _("Bienvenido a ..."));
}

void wx009Frame::OnComboBox(wxCommandEvent& event)
{
    combobox *dlg = new combobox(this, dataCombobox);
    dlg->ShowModal();
    if(dataCombobox.opcion!=wxEmptyString) {
        if(wxNOT_FOUND == dataCombobox.lista.Index(dataCombobox.opcion)) {
            dataCombobox.lista.Insert(dataCombobox.opcion, 0);
            if(dataCombobox.lista.GetCount()>10) {
                dataCombobox.lista.Remove(dataCombobox.lista.Last());
            }
        } else {
            dataCombobox.lista.Remove(dataCombobox.opcion);
            dataCombobox.lista.Insert(dataCombobox.opcion, 0);
        }
    }

    wxMessageBox(dataCombobox.opcion, _T("Respuesta"));
}

void wx009Frame::OnBitmapComboBox(wxCommandEvent& event)
{
    bitmapcombobox *dlg = new bitmapcombobox(this, dataBitmapCombobox);
    dlg->ShowModal();

    wxMessageBox(dataBitmapCombobox.opcion, _T("Respuesta"));
}
